pub async fn list(
client: &JiraClient,
out: &OutputConfig,
custom_only: bool,
) -> Result<(), ApiError>Expand description
List all available fields, optionally showing only custom fields.
pub async fn list(
client: &JiraClient,
out: &OutputConfig,
custom_only: bool,
) -> Result<(), ApiError>List all available fields, optionally showing only custom fields.