pub async fn attach(
client: &JiraClient,
out: &OutputConfig,
key: &str,
files: &[PathBuf],
) -> Result<(), ApiError>Expand description
Upload one or more local files to an issue.
pub async fn attach(
client: &JiraClient,
out: &OutputConfig,
key: &str,
files: &[PathBuf],
) -> Result<(), ApiError>Upload one or more local files to an issue.