Module config

Module config 

Structs

Config
Resolved credentials for a single profile.
ProfileConfig

Functions

init
Interactively set up the config file, or print JSON instructions when --json is used.
recommended_permissions
remove_profile
Remove a named profile from the config file.
schema_config_path
schema_config_path_description
schema_recommended_permissions_example
show
Print the config file path and current resolved values (masking the token).