pub fn contract_for(err: &ApiError) -> &'static ErrorContractExpand description
The contract row describing how this error is reported.
pub fn contract_for(err: &ApiError) -> &'static ErrorContractThe contract row describing how this error is reported.