contract_for_dyn

Function contract_for_dyn 

pub fn contract_for_dyn(err: &(dyn Error + 'static)) -> &'static ErrorContract
The contract row for any error, falling back to unexpected_error for errors that did not originate as an ApiError.