Structs
- Board
- A Jira Agile board.
- Board
Search Response - Paginated board response from the Agile API.
- Comment
- Comment
List - Create
Issue Response - Response from creating an issue.
- Field
- A Jira field (system or custom).
- Field
Schema - The schema of a field, describing its type.
- Issue
- Jira issue as returned by the search and issue endpoints.
- Issue
Fields - Issue
Link - An issue link (relationship between two issues).
- Issue
Link Type - The type of an issue link (e.g. “Blocks”, “Duplicate”).
- Issue
Type Field - Linked
Issue - A summary view of an issue referenced in a link.
- Linked
Issue Fields - Myself
- Current authenticated user.
- Priority
Field - Project
- Jira project.
- Project
Search Response - Response from the paginated project search endpoint.
- Search
Response - Response from the Jira search endpoint.
- Sprint
- A Jira sprint.
- Sprint
Search Response - Paginated sprint response from the Agile API.
- Status
Category - Workflow category for a status (e.g. “new”, “indeterminate”, “done”).
- Status
Field - Transition
- A single issue transition (workflow action).
- Transition
To - The target status of a transition.
- Transitions
Response - Response from the transitions endpoint.
- User
- A Jira user returned from the user search endpoint.
- User
Field - Worklog
Entry - A single worklog entry on an issue.
Functions
- escape_
jql - Escape a value for use inside a JQL double-quoted string literal.
- extract_
adf_ text - Extract plain text from an ADF node or a plain string value.
- text_
to_ adf - Build an Atlassian Document Format document from plain text.