Module types

Module types 

Structs

Comment
CommentList
CreateIssueResponse
Response from creating an issue.
Issue
Jira issue as returned by the search and issue endpoints.
IssueFields
IssueTypeField
Myself
Current authenticated user.
PriorityField
Project
Jira project.
ProjectSearchResponse
Response from the paginated project search endpoint.
SearchResponse
Response from the Jira search endpoint.
StatusCategory
Workflow category for a status (e.g. “new”, “indeterminate”, “done”).
StatusField
Transition
A single issue transition (workflow action).
TransitionTo
The target status of a transition.
TransitionsResponse
Response from the transitions endpoint.
UserField

Functions

escape_jql
Escape a value for use inside a JQL double-quoted string literal.
extract_adf_text
Extract plain text from an Atlassian Document Format node.
text_to_adf
Build an Atlassian Document Format document from plain text.