Structs
- Comment
- Comment
List - Create
Issue Response - Response from creating an issue.
- Issue
- Jira issue as returned by the search and issue endpoints.
- Issue
Fields - Issue
Type Field - Myself
- Current authenticated user.
- Priority
Field - Project
- Jira project.
- Project
Search Response - Response from the paginated project search endpoint.
- Search
Response - Response from the Jira search endpoint.
- Status
Category - Workflow category for a status (e.g. “new”, “indeterminate”, “done”).
- Status
Field - Transition
- A single issue transition (workflow action).
- Transition
To - The target status of a transition.
- Transitions
Response - Response from the transitions endpoint.
- User
Field
Functions
- escape_
jql - Escape a value for use inside a JQL double-quoted string literal.
- extract_
adf_ text - Extract plain text from an Atlassian Document Format node.
- text_
to_ adf - Build an Atlassian Document Format document from plain text.