Structs
- Config
- Resolved credentials for a single profile.
- Profile
Config
Functions
- init
- Interactively set up the config file, or print JSON instructions when
--jsonis used. - recommended_
permissions - remove_
profile - Remove a named profile from the config file.
- schema_
config_ path - schema_
config_ path_ description - schema_
recommended_ permissions_ example - show
- Print the config file path and current resolved values (masking the token).