Module config

Module config 

Structs

Config
Resolved credentials for a single profile.
ProfileConfig

Functions

init
Print example config file and instructions for obtaining an API token.
recommended_permissions
schema_config_path
schema_config_path_description
schema_recommended_permissions_example
show
Print the config file path and current resolved values (masking the token).