Structs
- Config
- Resolved credentials for a single profile.
- Profile
Config
Functions
- init
- Print example config file and instructions for obtaining an API token.
- recommended_
permissions - schema_
config_ path - schema_
config_ path_ description - schema_
recommended_ permissions_ example - show
- Print the config file path and current resolved values (masking the token).