pub fn init(out: &OutputConfig, host: Option<&str>)Expand description
Print example config file and instructions for obtaining an API token.
Pass host (e.g. "jira.mycompany.com") to include a one-click URL to the
Personal Access Token creation page on a Jira DC/Server instance. When omitted
the URL is shown as a template placeholder.