pub fn contract_for_dyn(err: &(dyn Error + 'static)) -> &'static ErrorContractExpand description
The contract row for any error, falling back to unexpected_error for
errors that did not originate as an ApiError.
pub fn contract_for_dyn(err: &(dyn Error + 'static)) -> &'static ErrorContractThe contract row for any error, falling back to unexpected_error for
errors that did not originate as an ApiError.